# ALAT (Advanced Linear Algebra Toolkit) 

ALAT is a collection of linear algerba applications and offers so many techniques 
to automate calculations. I've developed this project to help me in linear algebra 
lesson, and then noticed that it began bigger than I thought. So I decided to pack 
all of the tehniques, calculations and methods in one project and than ALAT was 
born. In this process, I've made so many major changes. Lately, I'm publishing the 
lastest version of this project. I've separated ALAT into 5 different modules. 
These are `matrices`, `vectors`, `apps`, `crypts` and `complexes`.

+ In `matrices` module, I've developed so many matrix operations from basic to advanced 
techniques like matrix checking, determinant, solving linear equations or so on. It 
is the biggest module in ALAT.

+ In `vectors` module, I've written a lot of vector operations. These operations can be 
made in different coordinate systems, different dimension of vectors. So I think it 
is useful to solve engineering mathematics problems.

+ In `apps` module, there are four linear algebra applications. These are polynomial 
curve fitting, least squares regression, finding area of triangular using 
determinant and finding volume of tetrahedron using determinant. I've found 
these topics in linear algera books. Also I've encounter different applications, 
but for now, I'm not putting those in this version. I hope that those will be in 
next version.

+ In `crypts` module, I've implemented the four cryptography applications. The main aim 
of this module is to encode messages into matrices using encoder matrix. So, 
related functions is defined in here.

+ In `complexes` module, there are complex number applications. I'm packing this module 
newly in this version. So ALAT is growing increasingly.

Also, I'm adding the examples of these applications in every function description. 
You can find how to use these modules.

